diff options
| author | Tom Englund <tomenglund26@gmail.com> | 2024-11-22 02:47:51 +0100 |
|---|---|---|
| committer | GitHub <noreply@github.com> | 2024-11-22 01:47:51 +0000 |
| commit | 943b3d467b0a77a6b67df01e78f5e4977486824f (patch) | |
| tree | 5ace2ff2943bf78d12e21cecf1789fb6a44a64f1 /src/managers/KeybindManager.cpp | |
| parent | 940f7aa990dbc99815bab8d355999d8277534b17 (diff) | |
bezier: optimize setup of bezier curves (#8528)
avoid reallocations by resizing and copy the pVec into the resized
m_dPoints, reduce the amount of calculations in baking to only do it
once per iteration instead of twice. precompute in getYforT and getXforT
return early in getYForPoint if x is equal or below 0. and use const
references where we can.
these changes we are now down to an average of "time to bake: 2.50µs."
on my machine compared to before average of "time to bake: 11.15µs"
Diffstat (limited to 'src/managers/KeybindManager.cpp')
0 files changed, 0 insertions, 0 deletions
